@@ -61,7 +61,7 @@ class Cloud_Connect_AWS:
             
             return self.result_obj
 
-    def QueryAWSAccounts(self, parameters):
+    def QueryAWSAccounts(self, parameters={}):
         """ Search for provisioned AWS Accounts by providing an FQL filter and paging details. 
             Returns a set of AWS accounts which match the filter criteria. 
         """
@@ -69,12 +69,11 @@ class Cloud_Connect_AWS:
         FULL_URL = self.base_url+'/cloud-connect-aws/combined/accounts/v1'
         HEADERS = self.headers
         PARAMS = parameters
-        result = self.Result()
         try:
             response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
-            returned = result(response.status_code, response.headers, response.json())
+            returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
-            returned = result(500, {}, str(e))
+            returned = self.Result()(500, {}, str(e))
         
         return returned
 
@@ -83,58 +82,52 @@ class Cloud_Connect_AWS:
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/cloud-connect-aws/GetAWSSettings
         FULL_URL = self.base_url+'/cloud-connect-aws/combined/settings/v1'
         HEADERS = self.headers
-        result = self.Result()
         try:
             response = requests.request("GET", FULL_URL, headers=HEADERS, verify=False)
-            returned = result(response.status_code, response.headers, response.json())
+            returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
-            returned = result(500, {}, str(e))
+            returned = self.Result()(500, {}, str(e))
             
         return returned
 
-    def GetAWSAccounts(self, parameters, ids):
+    def GetAWSAccounts(self, ids):
         """ Retrieve a set of AWS Accounts by specifying their IDs."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/cloud-connect-aws/GetAWSAccounts
         ID_LIST = str(ids).replace(",","&ids=")
         FULL_URL = self.base_url+'/cloud-connect-aws/entities/accounts/v1?ids={}'.format(ID_LIST)
         HEADERS = self.headers
-        PARAMS = parameters
-        result = self.Result()
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
-            returned = result(response.status_code, response.headers, response.json())
+            response = requests.request("GET", FULL_URL, headers=HEADERS, verify=False)
+            returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
-            returned = result(500, {}, str(e))
+            returned = self.Result()(500, {}, str(e))
 
         return returned
         
-    def ProvisionAWSAccounts(self, parameters, body):
+    def ProvisionAWSAccounts(self, body, parameters={}):
         """ Provision AWS Accounts by specifying details about the accounts to provision. """
         # [POST] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/cloud-connect-aws/ProvisionAWSAccounts
         FULL_URL = self.base_url+'/cloud-connect-aws/entities/accounts/v1'
         PARAMS=parameters
         BODY=body
-        result = self.Result()
         try:
             response = requests.request("POST", FULL_URL, params=PARAMS, json=BODY, headers=self.headers, verify=False)
-            returned = result(response.status_code, response.headers, response.json())
+            returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
-            returned = result(500, {}, str(e))
+            returned = self.Result()(500, {}, str(e))
 
         return returned
         
-    def DeleteAWSAccounts(self, parameters, ids):
+    def DeleteAWSAccounts(self, ids):
         """ Delete a set of AWS Accounts by specifying their IDs. """
         # [DELETE] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/cloud-connect-aws/DeleteAWSAccounts
         ID_LIST = str(ids).replace(",","&ids=")
         FULL_URL = self.base_url+'/cloud-connect-aws/entities/accounts/v1?ids={}'.format(ID_LIST)
-        PARAMS = parameters
-        result = self.Result()
         try:
-            response = requests.request("DELETE", FULL_URL, params=PARAMS, headers=self.headers, verify=False)
-            returned = result(response.status_code, response.headers, response.json())
+            response = requests.request("DELETE", FULL_URL, headers=self.headers, verify=False)
+            returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
-            returned = result(500, {}, str(e))
+            returned = self.Result()(500, {}, str(e))
         
         return returned
 
@@ -143,12 +136,11 @@ class Cloud_Connect_AWS:
         # [PATCH] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/cloud-connect-aws/UpdateAWSAccounts
         FULL_URL = self.base_url+'/cloud-connect-aws/entities/accounts/v1'
         BODY=body
-        result = self.Result()
         try:
             response = requests.request("PATCH", FULL_URL, json=BODY, headers=self.headers, verify=False)
-            returned = result(response.status_code, response.headers, response.json())
+            returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
-            returned = result(500, {}, str(e))
+            returned = self.Result()(500, {}, str(e))
         
         return returned
 
@@ -158,33 +150,30 @@ class Cloud_Connect_AWS:
         FULL_URL = self.base_url+'/cloud-connect-aws/entities/settings/v1'
         HEADERS = self.headers
         BODY = body
-        result = self.Result()
         try:
             response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=False)
-            returned = result(response.status_code, response.headers, response.json())
+            returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
-            returned = result(500, {}, str(e))
+            returned = self.Result()(500, {}, str(e))
             
         return returned
 
-    def VerifyAWSAccountAccess(self, parameters, body, ids):
+    def VerifyAWSAccountAccess(self, ids, body={}):
         """ Performs an Access Verification check on the specified AWS Account IDs. """
         # [POST] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/cloud-connect-aws/VerifyAWSAccountAccess
         ID_LIST = str(ids).replace(",","&ids=")
         FULL_URL = self.base_url+'/cloud-connect-aws/entities/verify-account-access/v1?ids={}'.format(ID_LIST)
         HEADERS = self.headers
-        PARAMS = parameters
-        BODY = body  #payload does not appear to be required
-        result = self.Result()
+        BODY=body
         try:
-            response = requests.request("POST", FULL_URL, json=BODY, params=PARAMS, headers=HEADERS, verify=False)
-            returned = result(response.status_code, response.headers, response.json())
+            response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=False)
+            returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
-            returned = result(500, {}, str(e))
+            returned = self.Result()(500, {}, str(e))
         
         return returned
 
-    def QueryAWSAccountsForIDs(self, parameters):
+    def QueryAWSAccountsForIDs(self, parameters={}):
         """ Search for provisioned AWS Accounts by providing an FQL filter and paging details. 
             Returns a set of AWS account IDs which match the filter criteria. 
         """
@@ -192,11 +181,10 @@ class Cloud_Connect_AWS:
         FULL_URL = self.base_url+'/cloud-connect-aws/queries/accounts/v1'
         HEADERS = self.headers
         PARAMS = parameters
-        result = self.Result()
         try:
             response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
-            returned = result(response.status_code, response.headers, response.json())
+            returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
-            returned = result(500, {}, str(e))
+            returned = self.Result()(500, {}, str(e))
             
         return returned
